@@ -1,14 +1,14 @@
 import inspect
 import unittest
 from functools import partial
-from typing import Iterable, List
+from typing import Iterable, List, Dict
 
 from testy_quick.functions import create_test
 from testy_quick.structures import TestyRunner, TestyCase
 
 
 class SimpleTester():
-    def __init__(self, test_cases: Iterable[TestyCase]):
+    def __init__(self, test_cases: Dict[TestyCase]):
         self.test_cases = test_cases
 
     def create_tests(self) -> List[TestyRunner]:
